<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                xmlns:rss="http://purl.org/rss/1.0/"
                xmlns:dc="http://purl.org/dc/elements/1.1/"
                xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
                xmlns:content="http://purl.org/rss/1.0/modules/content/"
                version="1.0">

<!--
name            : rdf.xsl
version         : 1.0
creationDate    : 14/05/2006
author          : ph03y3nk@users.sourceforge.net
copyright       : GNU/GPL
description     : XSL stylesheet for RSS 1.0 output 
-->

<xsl:output method="html"/>
<xsl:template match="/">
    <html>
        <head>
            <title><xsl:value-of select="rdf:RDF/rss:channel/rss:title"/> (RSS 1.0 feed)</title>
              <xsl:element name="meta">
                <xsl:attribute name="content-type">text/html; charset=iso-8859-1</xsl:attribute>
              </xsl:element>
              <xsl:element name="link">
                <xsl:attribute name="rel">stylesheet</xsl:attribute>
                <xsl:attribute name="href">./templates/rss_feeds/rss.css</xsl:attribute>
                <xsl:attribute name="type">text/css</xsl:attribute>
                <xsl:attribute name="title">mainlook</xsl:attribute>
              </xsl:element>
              <xsl:element name="link">
                <xsl:attribute name="rel">alternate</xsl:attribute>
                <xsl:attribute name="href">./templates/rss_feeds/rdf.xsl</xsl:attribute>
                <xsl:attribute name="type">application/rss+xml</xsl:attribute>
                <xsl:attribute name="title">rss</xsl:attribute>
              </xsl:element>
        </head>

        <body>
            <xsl:call-template name="output_intro"/>
            <dl>
            <xsl:for-each select="/rdf:RDF/rss:item">
                <!-- <xsl:sort select="dc:date" order="ascending"/> -->
                <xsl:call-template name="display_item">
                    <xsl:with-param name="full" select="1"/>
                </xsl:call-template>
            </xsl:for-each>
            </dl>

            <p class='end'>[<a href="{rdf:RDF/rss:channel/@rdf:about}">Back to Mainpage</a>]</p>
            
            <p class="badcss">
            Hm, you're apparently using a browser that doesn't
            support stylesheets properly<em style="display: none">, or at all</em>.
            You should really think about using
            <a href="http://www.mozilla.org/products/firefox/">Firefox</a>
            instead.
            </p>
            
        </body>
    </html>
</xsl:template>

<xsl:template name="output_intro">
    <xsl:comment>Generated from a RSS 1.0 feed by a XSLT style sheet.</xsl:comment>
    <div class="meantForReader">Don't panic!!! This is a RSS feed. This web page is
    actually a XML data file that is meant to be read by RSS reader programs (news aggregator). 
    It is not intended to be read through a browser, although we've used XSL stylesheet that transforms the data into something nice for browsers.
    <p>Add <a href="{rdf:RDF/rss:channel/@rdf:about}/backend.php?feed=1.0">this link</a> into your news aggregator so you can receive up to date information about this feed.</p>
    </div>

    <blockquote class='aboutThisFeed'>
            <p><em>Feed update:</em>
              <xsl:value-of select="rdf:RDF/rss:channel/dc:date"/>
            </p>
    </blockquote>
    

    <h1 class="feedtitle">
        <a href="{rdf:RDF/rss:channel/@rdf:about}"><xsl:value-of select="rdf:RDF/rss:channel/rss:title"/></a>
    </h1>
    
    <xsl:if test="rdf:RDF/rss:channel/rss:description != rdf:RDF/rss:channel/rss:title" >
        <!-- no point in printing them both if they're the same -->
        <p class='desc'><xsl:value-of select="rdf:RDF/rss:channel/rss:description"/></p>
    </xsl:if>

    <xsl:variable name="C" select="count(/rdf:RDF/rss:item)" />
    <p class='leadIn'>
      <xsl:choose>
        <xsl:when test="$C = 0" >No items </xsl:when>
        <xsl:when test="$C = 1" >The only item </xsl:when>
        <xsl:otherwise>Total <xsl:value-of select="$C" /> items </xsl:otherwise>
      </xsl:choose>
      currently in this feed:
    </p>

</xsl:template>


<xsl:template name="display_properties">
    <dl>
    <xsl:if test="dc:language!=''">
        <dt>Language:</dt> <dd><xsl:value-of select="dc:language"/></dd>
    </xsl:if>
    <xsl:if test="dc:creator!=''">
        <dt>Creator:</dt> <dd><xsl:value-of select="dc:creator"/></dd>
    </xsl:if>
    <xsl:if test="dc:subject!=''">
        <dt>Subject:</dt> <dd><xsl:value-of select="dc:subject"/></dd>
    </xsl:if>
    <xsl:if test="dc:date!=''">
        <dt class="date">Last Modified :</dt> <dd class="date"><xsl:value-of select="dc:date"/></dd>
    </xsl:if>
    </dl>
</xsl:template>

<xsl:template name="display_description">
    <div class="description">
    <dd>
        <xsl:value-of select="rss:description" disable-output-escaping="yes"/>
    </dd>
    </div>
</xsl:template>

<xsl:template name="display_item">
    <xsl:param name="full"/>
    <xsl:variable name="title" select="rss:title"/>
    <xsl:variable name="type" select="dc:type"/>
    <xsl:choose>
        <xsl:when test="$full=1">
            <div class="Items">
            <dt>
                 <a href="{rss:link}">
                <xsl:choose>
                <xsl:when test="string-length($title)">
                    <xsl:value-of select="rss:title"/>
                </xsl:when>
                <xsl:otherwise>
                     <xsl:value-of select="rss:link"/>
                </xsl:otherwise>
                </xsl:choose>
                </a>
            </dt>
            </div>

            <xsl:call-template name="display_description"/>
            <xsl:if test="content:encoded">
                <div class="content">
                    <xsl:value-of select="content:encoded" disable-output-escaping="yes"/>
                </div>
            </xsl:if>
                <xsl:call-template name="display_properties"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="position()"/> - <a href="#item{position()}"><xsl:value-of select="rss:title"/></a><br/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

</xsl:stylesheet>